@@ -1,26 +1,4 @@
-/*
-Copyright (C) 2001-2006, William Joseph.
-All Rights Reserved.
-
-This file is part of GtkRadiant.
-
-GtkRadiant is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-GtkRadiant is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with GtkRadiant; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-*/
-
-#if !defined(INCLUDED_MODELSKIN_H)
-#define INCLUDED_MODELSKIN_H
+#pragma once
 
 #include <vector>
 #include "imodule.h"
@@ -106,7 +84,8 @@ public:
 	virtual void refresh() = 0;
 };
 
-inline ModelSkinCache& GlobalModelSkinCache() {
+inline ModelSkinCache& GlobalModelSkinCache()
+{
 	std::shared_ptr<ModelSkinCache> _skinCache(
 		std::static_pointer_cast<ModelSkinCache>(
 			module::GlobalModuleRegistry().getModule(MODULE_MODELSKINCACHE)
@@ -114,5 +93,3 @@ inline ModelSkinCache& GlobalModelSkinCache() {
 	);
 	return *_skinCache;
 }
-
-#endif
