@@ -46,10 +46,10 @@
 #include "imap.h"
 #include "imapformat.h"
 #include "imapinfofile.h"
-//#include "imapcompiler.h"
 #include "imapresource.h"
 #include "imd5anim.h"
 #include "imd5model.h"
+#include "imediabrowser.h"
 #include "imenu.h"
 #include "imodel.h"
 #include "imodelcache.h"
@@ -74,9 +74,9 @@
 #include "irender.h"
 #include "irenderable.h"
 #include "irendersystemfactory.h"
+#include "iresourcechooser.h"
 #include "iscenegraph.h"
 #include "iscenegraphfactory.h"
-#include "iscript.h"
 #include "iselectable.h"
 #include "iselection.h"
 #include "iselectiongroup.h"
