@@ -39,31 +39,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #define OS_CASE_INSENSITIVE
 #endif
 
-/// \brief Returns true if \p path is lexicographically sorted before \p other.
-/// If both \p path and \p other refer to the same file, neither will be sorted before the other.
-/// O(n)
-inline bool path_less(const char* path, const char* other)
-{
-#if defined(OS_CASE_INSENSITIVE)
-  return string_less_nocase(path, other);
-#else
-  return string_less(path, other);
-#endif
-}
-
-/// \brief Returns <0 if \p path is lexicographically less than \p other.
-/// Returns >0 if \p path is lexicographically greater than \p other.
-/// Returns 0 if both \p path and \p other refer to the same file.
-/// O(n)
-inline int path_compare(const char* path, const char* other)
-{
-#if defined(OS_CASE_INSENSITIVE)
-  return string_compare_nocase(path, other);
-#else
-  return string_compare(path, other);
-#endif
-}
-
 /// \brief Returns true if the first \p n bytes of \p path and \p other form paths that refer to the same file or directory.
 /// If the paths are UTF-8 encoded, [\p path, \p path + \p n) must be a complete path.
 /// O(n)
@@ -89,18 +64,6 @@ inline bool path_is_absolute(const char* path)
 #endif
 }
 
-/// \brief Returns true if \p path is a directory.
-/// O(n)
-inline bool path_is_directory(const char* path)
-{
-  std::size_t length = strlen(path);
-  if(length > 0)
-  {
-    return path[length-1] == '/';
-  }
-  return false;
-}
-
 /// \brief Returns a pointer to the first character of the component of \p path following the first directory component.
 /// O(n)
 inline const char* path_remove_directory(const char* path)
@@ -113,42 +76,6 @@ inline const char* path_remove_directory(const char* path)
   return "";
 }
 
-/// \brief Returns a pointer to the first character of the filename component of \p path.
-/// O(n)
-inline const char* path_get_filename_start(const char* path)
-{
-  {
-    const char* last_forward_slash = strrchr(path, '/');
-    if(last_forward_slash != 0)
-    {
-      return last_forward_slash + 1;
-    }
-  }
-
-  // not strictly necessary,since paths should not contain '\'
-  {
-    const char* last_backward_slash = strrchr(path, '\\');
-    if(last_backward_slash != 0)
-    {
-      return last_backward_slash + 1;
-    }
-  }
-
-  return path;
-}
-
-/// \brief Returns a pointer to the first character of the file extension of \p path, or "" if not found.
-/// O(n)
-inline const char* path_get_extension(const char* path)
-{
-  const char* last_period = strrchr(path_get_filename_start(path), '.');
-  if(last_period != 0)
-  {
-    return ++last_period;
-  }
-  return "";
-}
-
 /** General utility functions for OS-related tasks
  */
 namespace os
@@ -264,4 +191,13 @@ namespace os
         lastSlash = trimmed.rfind('/');
         return trimmed.substr(lastSlash + 1);
     }
+
+	/**
+	 * Returns true if the given string qualifies as path to a directory,
+	 * which is equal to the path string ending with the slash '/' character.
+	 */
+	inline bool isDirectory(const std::string& path)
+	{
+		return !path.empty() && path.back() == '/';
+	}
 }
