@@ -168,7 +168,7 @@ void ParticlePreview::setupSceneGraph()
 
 	try
 	{
-        _rootNode.reset(new scene::BasicRootNode);
+        _rootNode = std::make_shared<scene::BasicRootNode>();
         
 		_entity = GlobalEntityCreator().createEntity(
 			GlobalEntityClassManager().findClass(FUNC_EMITTER_CLASS));
