@@ -5,17 +5,22 @@
 
 #include "pkzip.h"
 #include "zlibstream.h"
+#include "os/fs.h"
+#include "os/path.h"
 
 #include "DeflatedArchiveFile.h"
 #include "DeflatedArchiveTextFile.h"
 
 ZipArchive::ZipArchive(const std::string& name) :
 	m_name(name),
+	_containingFolder(os::standardPathWithSlash(fs::path(name).remove_filename())),
 	m_istream(name)
 {
-	if (!m_istream.failed()) {
-		if (!read_pkzip()) {
-			rError() << "ERROR: invalid zip-file " << name.c_str() << '\n';
+	if (!m_istream.failed())
+	{
+		if (!read_pkzip())
+		{
+			rError() << "ERROR: invalid zip-file " << name << std::endl;
 		}
 	}
 }
@@ -78,8 +83,6 @@ ArchiveTextFilePtr ZipArchive::openTextFile(const std::string& name)
     {
 		ZipRecord* file = i->second.file();
 
-        FileInputStream::size_type position = 0;
-
         {
             // Guard against concurrent access
             std::lock_guard<std::mutex> lock(_streamLock);
@@ -100,14 +103,14 @@ ArchiveTextFilePtr ZipArchive::openTextFile(const std::string& name)
 			case ZipRecord::eStored:
 				return ArchiveTextFilePtr(new StoredArchiveTextFile(name,
 					m_name,
-					m_name,
+					_containingFolder,
 					m_istream.tell(),
 					file->m_stream_size));
 
 			case ZipRecord::eDeflated:
 				return ArchiveTextFilePtr(new DeflatedArchiveTextFile(name,
 					m_name,
-					m_name,
+					_containingFolder,
 					m_istream.tell(),
 					file->m_stream_size));
 		}
@@ -179,17 +182,22 @@ bool ZipArchive::read_record() {
 
 	m_istream.seek(extras + comment, FileInputStream::cur);
 
-	if (path_is_directory(path.c_str())) {
+	if (os::isDirectory(path))
+	{
 		m_filesystem[path] = 0;
 	}
-	else {
+	else
+	{
 		ZipFileSystem::entry_type& file = m_filesystem[path];
-		if (!file.is_directory()) {
+
+		if (!file.is_directory())
+		{
 			rMessage() << "Warning: zip archive "
 				<< m_name << " contains duplicated file: "
 				<< path << std::endl;
 		}
-		else {
+		else 
+		{
 			file = new ZipRecord(position,
 								 compressed_size,
 								 uncompressed_size,
