@@ -4,9 +4,12 @@
 #include "string/string.h"
 
 #include <boost/format.hpp>
-#include <boost/regex.hpp>
+#include <boost/algorithm/string/join.hpp>
+#include <regex>
 
 #include "CommandEditor.h"
+#include "ActorNodeFinder.h"
+#include "wxutil/dialog/MessageBox.h"
 
 #include <wx/button.h>
 #include <wx/sizer.h>
@@ -102,6 +105,10 @@ void ConversationEditor::populateWindow()
 	_delActorButton->Connect(wxEVT_BUTTON, wxCommandEventHandler(ConversationEditor::onDeleteActor), NULL, this);
 	_delActorButton->Enable(false);
 
+	_validateActorsButton = findNamedObject<wxButton>(this, "ConvEditorValidateActorsButton");
+	_validateActorsButton->Connect(wxEVT_BUTTON, wxCommandEventHandler(ConversationEditor::onValidateActors), NULL, this);
+	_validateActorsButton->Enable(false);
+
 	// Command Panel
 	wxPanel* commandPanel = findNamedObject<wxPanel>(this, "ConvEditorCommandPanel");
 	
@@ -161,6 +168,8 @@ void ConversationEditor::updateWidgets()
 	updateCmdActionSensitivity(false);
 	_delActorButton->Enable(false);
 
+	_validateActorsButton->Enable(!_conversation.actors.empty());
+
 	// Name
 	findNamedObject<wxTextCtrl>(this, "ConvEditorNameEntry")->SetValue(_conversation.name);
 
@@ -432,6 +441,33 @@ void ConversationEditor::onDeleteActor(wxCommandEvent& ev)
 	updateWidgets();
 }
 
+void ConversationEditor::onValidateActors(wxCommandEvent& ev)
+{
+	std::vector<std::string> errors;
+
+	for (const conversation::Conversation::ActorMap::value_type& i : _conversation.actors)
+	{
+		scene::ActorNodeFinder finder(i.second);
+		GlobalSceneGraph().root()->traverse(finder);
+
+		if (!finder.getFoundNode())
+		{
+			errors.push_back((boost::format(_("The actor %s cannot be found in the current map.")) % i.second).str());
+		}
+	}
+
+	if (!errors.empty())
+	{
+		std::string message = boost::algorithm::join(errors, "\n");
+		wxutil::Messagebox::Show(_("Actors missing"), message, IDialog::MESSAGE_ERROR, this);
+	}
+	else
+	{
+		std::string message = _("All actors are correctly referring to entities in the map.");
+		wxutil::Messagebox::Show(_("Actors OK"), message, IDialog::MESSAGE_CONFIRM, this);
+	}
+}
+
 void ConversationEditor::onActorEdited(wxDataViewEvent& ev)
 {
 	wxutil::TreeModel::Row row(ev.GetItem(), *_actorStore);
@@ -546,8 +582,8 @@ void ConversationEditor::onDeleteCommand(wxCommandEvent& ev)
 
 std::string ConversationEditor::removeMarkup(const std::string& input)
 {
-	boost::regex expr("(<[A-Za-z]+>)|(</[A-Za-z]+>)");
-	return boost::regex_replace(input, expr, "");
+	std::regex expr("(<[A-Za-z]+>)|(</[A-Za-z]+>)");
+	return std::regex_replace(input, expr, "");
 }
 
 } // namespace ui
