@@ -11,15 +11,15 @@
 #include "selectionlib.h"
 #include "wxutil/dialog/MessageBox.h"
 
-#include <boost/filesystem/fstream.hpp>
-#include <boost/filesystem.hpp>
-
 #include "registry/registry.h"
 #include "string/string.h"
+#include "os/file.h"
+#include "os/path.h"
 #include "i18n.h"
 #include "itextstream.h"
 
 // Modules
+#include "iundo.h"
 #include "imainframe.h"
 #include "ientity.h"
 #include "imap.h"
@@ -44,9 +44,6 @@ namespace
 	const char* const NO_ENTITY_ERROR = N_("Cannot run Readable Editor on this selection.\n"
 		"Please select a single XData entity.");
 
-	const char* const LABEL_PAGE_RELATED = N_("Page Editing:");
-	const char* const LABEL_GENERAL_PROPERTIES = N_("General Properties:");
-
 	enum MenuItemId
 	{
 		InsertWholePage = 1,
@@ -360,6 +357,8 @@ bool ReadableEditorDialog::save()
 {
 	_saveInProgress = true;
 
+	UndoableCommand cmd("editReadable");
+
 	// Name
 	_entity->setKeyValue("inv_name", _nameEntry->GetValue().ToStdString());
 
@@ -372,7 +371,7 @@ bool ReadableEditorDialog::save()
 	// Get the storage path and check its validity
 	std::string storagePath = constructStoragePath();
 
-	if (!_useDefaultFilename && !boost::filesystem::exists(storagePath))
+	if (!_useDefaultFilename && !os::fileOrDirExists(storagePath))
 	{
 		// The file does not exist, so we have imported a definition contained inside a PK4.
 		wxutil::Messagebox::ShowError(
@@ -519,8 +518,17 @@ std::string ReadableEditorDialog::constructStoragePath()
 	}
 	else
 	{
-		// We are exporting a previously imported XData definition. Retrieve engine path and append _xdFilename
-		storagePath = GlobalRegistry().get(RKEY_ENGINE_PATH) + _xdFilename;
+		// We are exporting a previously imported XData definition. 
+		// The _xdFilename itself can be a VFS path or an absolute path, depending on the user's settings
+		if (path_is_absolute(_xdFilename.c_str()))
+		{
+			storagePath = _xdFilename;
+		}
+		else
+		{
+			// Retrieve engine path and append _xdFilename
+			storagePath = GlobalRegistry().get(RKEY_ENGINE_PATH) + _xdFilename;
+		}
 	}
 
 	return storagePath;
@@ -1192,11 +1200,11 @@ void ReadableEditorDialog::checkGuiLayout()
 	if (dialog.run() == ui::IDialog::RESULT_YES)
 	{
 		XData::PageLayout layoutBefore = _xData->getPageLayout();
-		std::string guiName = GuiSelector::Run(_xData->getPageLayout() == XData::TwoSided, this);
+		std::string selectedGuiName = GuiSelector::Run(_xData->getPageLayout() == XData::TwoSided, this);
 
-		if (!guiName.empty())
+		if (!selectedGuiName.empty())
 		{
-			_guiEntry->SetValue(guiName);
+			_guiEntry->SetValue(selectedGuiName);
 			_runningGuiLayoutCheck = false;
 			updateGuiView();
 			return;
