@@ -34,18 +34,15 @@
 namespace ui
 {
 
-	namespace
-    {
-		const std::string RKEY_DEBUG = "debug/ui/debugEventManager";
-	}
-
 // RegisterableModule implementation
-const std::string& EventManager::getName() const {
+const std::string& EventManager::getName() const
+{
 	static std::string _name(MODULE_EVENTMANAGER);
 	return _name;
 }
 
-const StringSet& EventManager::getDependencies() const {
+const StringSet& EventManager::getDependencies() const
+{
 	static StringSet _dependencies;
 
 	if (_dependencies.empty())
@@ -58,28 +55,19 @@ const StringSet& EventManager::getDependencies() const {
 
 void EventManager::initialiseModule(const ApplicationContext& ctx)
 {
-	rMessage() << "EventManager::initialiseModule called." << std::endl;
-
-	_debugMode = registry::getValue<bool>(RKEY_DEBUG);
+	rMessage() << getName() << "::initialiseModule called." << std::endl;
 
 	// Deactivate the empty event, so it's safe to return it as NullEvent
 	_emptyEvent->setEnabled(false);
 
-    _shortcutFilter.reset(new ui::GlobalKeyEventFilter(*this));
+    _shortcutFilter.reset(new GlobalKeyEventFilter(*this));
 
-	if (_debugMode)
-    {
-		rMessage() << "EventManager intitialised in debug mode." << std::endl;
-	}
-	else 
-    {
-		rMessage() << "EventManager successfully initialised." << std::endl;
-	}
+	rMessage() << getName() << " successfully initialised." << std::endl;
 }
 
 void EventManager::shutdownModule()
 {
-	rMessage() << "EventManager: shutting down." << std::endl;
+	rMessage() << getName() << "::shutdownModule called" << std::endl;
     _shortcutFilter.reset();
 
 	saveEventListToRegistry();
@@ -91,53 +79,67 @@ void EventManager::shutdownModule()
 // Constructor
 EventManager::EventManager() :
 	_emptyEvent(new Event()),
-	_emptyAccelerator(0, 0, _emptyEvent),
-	_debugMode(false)
+	_emptyAccelerator(0, 0, _emptyEvent)
 {}
 
-IAccelerator& EventManager::addAccelerator(const std::string& key, const std::string& modifierStr)
+Accelerator& EventManager::addAccelerator(const std::string& key, const std::string& modifierStr)
 {
 	unsigned int keyVal = Accelerator::getKeyCodeFromName(key);
     unsigned int modifierFlags = wxutil::Modifier::GetStateFromModifierString(modifierStr);
 
-	Accelerator accel(keyVal, modifierFlags, _emptyEvent);
-
 	// Add a new Accelerator to the list
-	_accelerators.push_back(accel);
+	_accelerators.push_back(Accelerator(keyVal, modifierFlags, _emptyEvent));
 
 	// return the reference to the last accelerator in the list
-	AcceleratorList::reverse_iterator i = _accelerators.rbegin();
-
-	return (*i);
+	return _accelerators.back();
 }
 
-IAccelerator& EventManager::addAccelerator(wxKeyEvent& ev)
+Accelerator& EventManager::addAccelerator(wxKeyEvent& ev)
 {
 	int keyCode = ev.GetKeyCode();
 	unsigned int modifierFlags = wxutil::Modifier::GetStateForKeyEvent(ev);
 
-	// Create a new accelerator with the given arguments
-	Accelerator accel(keyCode, modifierFlags, _emptyEvent);
-
-	// Add a new Accelerator to the list
-	_accelerators.push_back(accel);
+	// Create a new accelerator with the given arguments and add it
+	_accelerators.push_back(Accelerator(keyCode, modifierFlags, _emptyEvent));
 
 	// return the reference to the last accelerator in the list
-	return *_accelerators.rbegin();
+	return _accelerators.back();
 }
 
-IEventPtr EventManager::findEvent(const std::string& name) {
-	// Try to lookup the command
-	EventMap::iterator i = _events.find(name);
+void EventManager::resetAcceleratorBindings()
+{
+	// Select the stock mappings
+	std::string xPathQuery = "user/ui/input/shortcuts[@name='default']//shortcut";
 
-	if (i != _events.end()) {
-		// Return the pointer to the command
-		return i->second;
+	xml::NodeList shortcutList = GlobalRegistry().findXPath(xPathQuery);
+
+	if (shortcutList.empty())
+	{
+		// No accelerator definitions found!
+		rWarning() << "EventManager: No default shortcut definitions found..." << std::endl;
+		return;
 	}
-	else {
-		// Nothing found, return the NullEvent
-		return _emptyEvent;
+
+	// Disconnect all accelerators from all events
+	for (EventMap::value_type& pair : _events)
+	{
+		pair.second->disconnectAccelerators();
 	}
+
+	_accelerators.clear();
+
+	rMessage() << "EventManager: Default shortcuts found in Registry: " << shortcutList.size() << std::endl;
+
+	loadAcceleratorFromList(shortcutList);
+}
+
+IEventPtr EventManager::findEvent(const std::string& name) 
+{
+	// Try to lookup the command
+	const EventMap::iterator& found = _events.find(name);
+
+	// if nothing found, return the NullEvent
+	return found != _events.end() ? found->second : _emptyEvent;
 }
 
 IEventPtr EventManager::findEvent(wxKeyEvent& ev)
@@ -152,112 +154,126 @@ IEventPtr EventManager::findEvent(wxKeyEvent& ev)
 std::string EventManager::getEventName(const IEventPtr& event)
 {
 	// Try to lookup the given eventptr
-	for (EventMap::iterator i = _events.begin(); i != _events.end(); i++) {
-		if (i->second == event) {
-			return i->first;
+	for (const EventMap::value_type& pair : _events)
+	{
+		if (pair.second == event)
+		{
+			return pair.first;
 		}
 	}
 
-	return "";
+	return std::string();
 }
 
 std::string EventManager::getAcceleratorStr(const IEventPtr& event, bool forMenu)
 {
-	std::string returnValue = "";
-
 	IAccelerator& accelerator = findAccelerator(event);
 
     return static_cast<Accelerator&>(accelerator).getAcceleratorString(forMenu);
 }
 
-// Checks if the eventName is already registered and writes to rMessage, if so
-bool EventManager::alreadyRegistered(const std::string& eventName) {
+// Checks if the eventName is already registered and writes to rWarning, if so
+bool EventManager::alreadyRegistered(const std::string& eventName)
+{
 	// Try to find the command and see if it's already registered
 	IEventPtr foundEvent = findEvent(eventName);
 
-	if (foundEvent->empty()) {
+	if (foundEvent->empty())
+	{
 		return false;
 	}
-	else {
-		rWarning() << "EventManager: Event " << eventName
-			<< " already registered!" << std::endl;
-		return true;
-	}
+	
+	rWarning() << "EventManager: Event " << eventName << " already registered!" << std::endl;
+	return true;
 }
 
 // Add the given command to the internal list
-IEventPtr EventManager::addCommand(const std::string& name, const std::string& statement, bool reactOnKeyUp) {
-
-	if (!alreadyRegistered(name)) {
-		// Add the command to the list
-		_events[name] = IEventPtr(new Statement(statement, reactOnKeyUp));
-
-		// Return the pointer to the newly created event
-		return _events[name];
+IEventPtr EventManager::addCommand(const std::string& name, const std::string& statement, bool reactOnKeyUp)
+{
+	if (alreadyRegistered(name))
+	{
+		return _emptyEvent;
 	}
 
-	return _emptyEvent;
+	// Add the command to the list
+	IEventPtr event = std::make_shared<Statement>(statement, reactOnKeyUp);
+
+	_events[name] = event;
+
+	// Return the pointer to the newly created event
+	return event;
 }
 
-IEventPtr EventManager::addKeyEvent(const std::string& name, const ui::KeyStateChangeCallback& keyStateChangeCallback)
+IEventPtr EventManager::addKeyEvent(const std::string& name, const KeyStateChangeCallback& keyStateChangeCallback)
 {
-	if (!alreadyRegistered(name))
+	if (alreadyRegistered(name))
 	{
-		// Add the new keyevent to the list (implicitly cast onto Event&)
-		_events[name] = IEventPtr(new KeyEvent(keyStateChangeCallback));
-
-		// Return the pointer to the newly created event
-		return _events[name];
+		return _emptyEvent;
 	}
+	
+	IEventPtr event = std::make_shared<KeyEvent>(keyStateChangeCallback);
 
-	return _emptyEvent;
+	// Add the new keyevent to the list
+	_events[name] = event;
+
+	// Return the pointer to the newly created event
+	return event;
 }
 
 IEventPtr EventManager::addWidgetToggle(const std::string& name) {
 
-	if (!alreadyRegistered(name)) {
-		// Add the command to the list (implicitly cast the pointer on Event&)
-		_events[name] = IEventPtr(new WidgetToggle());
-
-		// Return the pointer to the newly created event
-		return _events[name];
+	if (alreadyRegistered(name))
+	{
+		return _emptyEvent;
 	}
+	
+	IEventPtr event = std::make_shared<WidgetToggle>();
 
-	return _emptyEvent;
+	// Add the command to the list
+	_events[name] = event;
+
+	// Return the pointer to the newly created event
+	return event;
 }
 
 IEventPtr EventManager::addRegistryToggle(const std::string& name, const std::string& registryKey)
 {
-	if (!alreadyRegistered(name)) {
-		// Add the command to the list (implicitly cast the pointer on Event&)
-		_events[name] = IEventPtr(new RegistryToggle(registryKey));
-
-		// Return the pointer to the newly created event
-		return _events[name];
+	if (alreadyRegistered(name))
+	{
+		return _emptyEvent;
 	}
 
-	return _emptyEvent;
+	IEventPtr event = std::make_shared<RegistryToggle>(registryKey);
+		
+	// Add the command to the list 
+	_events[name] = event;
+	
+	// Return the pointer to the newly created event
+	return event;
 }
 
 IEventPtr EventManager::addToggle(const std::string& name, const ToggleCallback& onToggled)
 {
-	if (!alreadyRegistered(name)) {
-		// Add the command to the list (implicitly cast the pointer on Event&)
-		_events[name] = IEventPtr(new Toggle(onToggled));
-
-		// Return the pointer to the newly created event
-		return _events[name];
+	if (alreadyRegistered(name))
+	{
+		return _emptyEvent;
 	}
 
-	return _emptyEvent;
+	IEventPtr event = std::make_shared<Toggle>(onToggled);
+
+	// Add the command to the list
+	_events[name] = event;
+
+	// Return the pointer to the newly created event
+	return event;
 }
 
 void EventManager::setToggled(const std::string& name, const bool toggled)
 {
 	// Check could be placed here by boost::shared_ptr's dynamic_pointer_cast
-	if (!findEvent(name)->setToggled(toggled)) {
-		rWarning() << "EventManager: Event " << name
-			<< " is not a Toggle." << std::endl;
+	if (!findEvent(name)->setToggled(toggled))
+	{
+		rWarning() << "EventManager: Event " << name << " is not a Toggle." << std::endl;
 	}
 }
 
@@ -306,19 +322,23 @@ void EventManager::disconnectAccelerator(const std::string& command)
 	}
 }
 
-void EventManager::disableEvent(const std::string& eventName) {
+void EventManager::disableEvent(const std::string& eventName) 
+{
 	findEvent(eventName)->setEnabled(false);
 }
 
-void EventManager::enableEvent(const std::string& eventName) {
+void EventManager::enableEvent(const std::string& eventName) 
+{
 	findEvent(eventName)->setEnabled(true);
 }
 
-void EventManager::removeEvent(const std::string& eventName) {
+void EventManager::removeEvent(const std::string& eventName) 
+{
 	// Try to lookup the command
 	EventMap::iterator i = _events.find(eventName);
 
-	if (i != _events.end()) {
+	if (i != _events.end()) 
+	{
 		// Remove all accelerators beforehand
 		disconnectAccelerator(eventName);
 
@@ -333,7 +353,7 @@ void EventManager::disconnectToolbar(wxToolBar* toolbar)
 	{
 		for (std::size_t tool = 0; tool < toolbar->GetToolsCount(); tool++)
 		{
-			pair.second->disconnectToolItem(const_cast<wxToolBarToolBase*>(toolbar->GetToolByPos(tool)));
+			pair.second->disconnectToolItem(const_cast<wxToolBarToolBase*>(toolbar->GetToolByPos(static_cast<int>(tool))));
 		}
 	});
 }
@@ -341,99 +361,85 @@ void EventManager::disconnectToolbar(wxToolBar* toolbar)
 // Loads the default shortcuts from the registry
 void EventManager::loadAccelerators()
 {
-	if (_debugMode) {
-        rConsole() << "EventManager: Loading accelerators..." << std::endl;
-	}
-
 	// Register all custom statements as events too to make them shortcut-bindable
 	// before going ahead
-	GlobalCommandSystem().foreachStatement([&] (const std::string& statementName)
+	GlobalCommandSystem().foreachStatement([&](const std::string& statementName)
 	{
 		addCommand(statementName, statementName, false);
 	}, true); // custom statements only
 
 	xml::NodeList shortcutSets = GlobalRegistry().findXPath("user/ui/input//shortcuts");
 
-	if (_debugMode) {
-        rConsole() << "Found " << shortcutSets.size() << " sets." << std::endl;
-	}
+	// If we have two sets of shortcuts, don't select the stock ones
+	std::string xPathQuery = shortcutSets.size() > 1 ?
+		"user/ui/input/shortcuts[not(@name)]//shortcut" : // find all without name attribute
+		"user/ui/input/shortcuts//shortcut"; // find all shortcuts
 
-	// If we have two sets of shortcuts, delete the default ones
-	if (shortcutSets.size() > 1) {
-		GlobalRegistry().deleteXPath("user/ui/input//shortcuts[@name='default']");
-	}
+	xml::NodeList shortcutList = GlobalRegistry().findXPath(xPathQuery);
 
-	// Find all accelerators
-	xml::NodeList shortcutList = GlobalRegistry().findXPath("user/ui/input/shortcuts//shortcut");
-
-	if (!shortcutList.empty())
-	{
-		rMessage() << "EventManager: Shortcuts found in Registry: " << shortcutList.size() << std::endl;
-
-		for (std::size_t i = 0; i < shortcutList.size(); i++)
-		{
-			const std::string key = shortcutList[i].getAttributeValue("key");
-			const std::string cmd = shortcutList[i].getAttributeValue("command");
-
-			if (_debugMode) 
-			{
-				rConsole() << "Looking up command: " << cmd << std::endl;
-				rConsole() << "Key is: >> " << key << " << " << std::endl;
-			}
-
-			// Try to lookup the command
-			IEventPtr event = findEvent(cmd);
-
-			// Check for a non-empty key string
-			if (!key.empty())
-			{
-				 // Check for valid command definitions were found
-				if (!event->empty())
-				{
-					// Get the modifier string (e.g. "SHIFT+ALT")
-					const std::string modifierStr = shortcutList[i].getAttributeValue("modifiers");
-
-					if (!duplicateAccelerator(key, modifierStr, event))
-					{
-						// Create the accelerator object
-						IAccelerator& accelerator = addAccelerator(key, modifierStr);
-
-						// Connect the newly created accelerator to the command
-                        event->connectAccelerator(accelerator);
-                        static_cast<Accelerator&>(accelerator).setEvent(event);
-					}
-				}
-				else
-				{
-					rWarning() << "EventManager: Cannot load shortcut definition (command invalid): " 
-						<< cmd << std::endl;
-				}
-			}
-		}
-	}
-	else 
+	if (shortcutList.empty())
 	{
 		// No accelerator definitions found!
 		rWarning() << "EventManager: No shortcut definitions found..." << std::endl;
+		return;
+	}
+
+	rMessage() << "EventManager: Shortcuts found in Registry: " << shortcutList.size() << std::endl;
+
+	loadAcceleratorFromList(shortcutList);
+}
+
+void EventManager::loadAcceleratorFromList(const xml::NodeList& shortcutList)
+{
+	for (const xml::Node& shortcutNode : shortcutList)
+	{
+		const std::string key = shortcutNode.getAttributeValue("key");
+		const std::string cmd = shortcutNode.getAttributeValue("command");
+
+		// Try to lookup the command
+		IEventPtr event = findEvent(cmd);
+
+		// Check for a non-empty key string
+		if (key.empty()) continue;
+
+		// Check for valid command definitions were found
+		if (!event->empty())
+		{
+			// Get the modifier string (e.g. "SHIFT+ALT")
+			const std::string modifierStr = shortcutNode.getAttributeValue("modifiers");
+
+			if (!duplicateAccelerator(key, modifierStr, event))
+			{
+				// Create the accelerator object
+				IAccelerator& accelerator = addAccelerator(key, modifierStr);
+
+				// Connect the newly created accelerator to the command
+                event->connectAccelerator(accelerator);
+                static_cast<Accelerator&>(accelerator).setEvent(event);
+			}
+		}
+		else
+		{
+			rWarning() << "EventManager: Cannot load shortcut definition (command invalid): " 
+				<< cmd << std::endl;
+		}
 	}
 }
 
-void EventManager::foreachEvent(IEventVisitor& eventVisitor) {
+void EventManager::foreachEvent(IEventVisitor& eventVisitor)
+{
 	// Cycle through the event and pass them to the visitor class
-	for (EventMap::iterator i = _events.begin(); i != _events.end(); i++) {
-		const std::string eventName = i->first;
-		IEventPtr event = i->second;
-
-		eventVisitor.visit(eventName, event);
+	for (const EventMap::value_type& pair : _events)
+	{
+		eventVisitor.visit(pair.first, pair.second);
 	}
 }
 
 // Tries to locate an accelerator, that is connected to the given command
-IAccelerator& EventManager::findAccelerator(const IEventPtr& event)
+Accelerator& EventManager::findAccelerator(const IEventPtr& event)
 {
 	// Cycle through the accelerators and check for matches
-    AcceleratorList::iterator end = _accelerators.end();
-    for (AcceleratorList::iterator i = _accelerators.begin(); i != end; ++i)
+    for (AcceleratorList::iterator i = _accelerators.begin(); i != _accelerators.end(); ++i)
     {
 		if (i->match(event))
         {
@@ -452,7 +458,7 @@ void EventManager::saveEventListToRegistry()
 
 	// The visitor class to save each event definition into the registry
 	// Note: the SaveEventVisitor automatically wipes all the existing shortcuts from the registry
-	SaveEventVisitor visitor(rootKey, this);
+	SaveEventVisitor visitor(rootKey, *this);
 
 	foreachEvent(visitor);
 }
@@ -472,10 +478,10 @@ bool EventManager::duplicateAccelerator(const std::string& key,
 {
 	AcceleratorList accelList = findAccelerator(key, modifiers);
 
-	for (AcceleratorList::iterator i = accelList.begin(); i != accelList.end(); ++i)
+	for (const Accelerator& accel : accelList)
     {
 		// If one of the accelerators in the list matches the event, return true
-		if (i->match(event))
+		if (accel.match(event))
         {
 			return true;
 		}
@@ -572,15 +578,8 @@ std::string EventManager::getEventStr(wxKeyEvent& ev)
 
 extern "C" void DARKRADIANT_DLLEXPORT RegisterModule(IModuleRegistry& registry)
 {
+	module::performDefaultInitialisation(registry);
+
     registry.registerModule(std::make_shared<ui::EventManager>());
     registry.registerModule(std::make_shared<ui::MouseToolManager>());
-
-	// Initialise the streams using the given application context
-	module::initialiseStreams(registry.getApplicationContext());
-
-	// Remember the reference to the ModuleRegistry
-	module::RegistryReference::Instance().setRegistry(registry);
-
-	// Set up the assertion handler
-	GlobalErrorHandler() = registry.getApplicationContext().getErrorHandlingFunction();
 }
