@@ -34,13 +34,12 @@
 
 #include <wx/frame.h>
 
+#include "os/fs.h"
+#include "os/file.h"
 #include "os/path.h"
-#include <boost/filesystem.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/python/suite/indexing/vector_indexing_suite.hpp>
 
-namespace fs = boost::filesystem;
-
 namespace script {
 
 ScriptingSystem::ScriptingSystem() :
@@ -62,7 +61,7 @@ void ScriptingSystem::addInterface(const std::string& name, const IScriptInterfa
 
 	if (_initialised) {
 		// Add the interface at once, all the others are already added
-		iface->registerInterface(_mainNamespace);
+		iface->registerInterface(_mainObjects->mainNamespace);
 	}
 }
 
@@ -84,7 +83,7 @@ void ScriptingSystem::executeScriptFile(const std::string& filename) {
 
         // Prevent calling exec_file with a non-existent file, we would
         // get crashes during Py_Finalize later on.
-        if (!boost::filesystem::exists(filePath))
+        if (!os::fileOrDirExists(filePath))
         { 
             rError() << "Error: File " << filePath << " doesn't exist." << std::endl;
             return;
@@ -93,8 +92,8 @@ void ScriptingSystem::executeScriptFile(const std::string& filename) {
 		// Attempt to run the specified script
 		boost::python::object ignored = boost::python::exec_file(
             filePath.c_str(),
-			_mainNamespace,
-			_globals
+			_mainObjects->mainNamespace,
+			_mainObjects->globals
 		);
 	}
     catch (std::invalid_argument& e) // thrown when the file doesn't exist
@@ -129,8 +128,8 @@ ExecutionResultPtr ScriptingSystem::executeString(const std::string& scriptStrin
 		// Attempt to run the specified script
 		boost::python::object ignored = boost::python::exec(
 			scriptString.c_str(),
-			_mainNamespace,
-			_globals
+			_mainObjects->mainNamespace,
+			_mainObjects->globals
 		);
 	}
 	catch (const boost::python::error_already_set&)
@@ -159,7 +158,7 @@ void ScriptingSystem::initialise()
 			// Handle each interface in its own try/catch block
 			try
 			{
-				i->second->registerInterface(_mainNamespace);
+				i->second->registerInterface(_mainObjects->mainNamespace);
 			}
 			catch (const boost::python::error_already_set&)
 			{
@@ -235,7 +234,7 @@ void ScriptingSystem::executeCommand(const std::string& name) {
 	}
 
 	// Set the execution flag in the global namespace
-	_globals["__executeCommand__"] = true;
+	_mainObjects->globals["__executeCommand__"] = true;
 
 	// Execute the script file behind this command
 	executeScriptFile(found->second->getFilename());
@@ -254,7 +253,7 @@ void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
 		// Attempt to run the specified script
 		boost::python::object ignored = boost::python::exec_file(
 			(_scriptPath + scriptFilename).c_str(),
-			_mainNamespace,
+			_mainObjects->mainNamespace,
 			locals	// pass the new dictionary for the locals
 		);
 
@@ -338,7 +337,7 @@ void ScriptingSystem::reloadScripts()
 		if (extension != "py") continue;
 
 		// Script file found, construct a new command
-		loadCommandScript(os::getRelativePath(candidate.string(), _scriptPath));
+		loadCommandScript(os::getRelativePath(candidate.generic_string(), _scriptPath));
 	}
 
 	rMessage() << "ScriptModule: Found " << _commands.size() << " commands." << std::endl;
@@ -382,7 +381,7 @@ void ScriptingSystem::initialiseModule(const ApplicationContext& ctx)
 #if defined(POSIX) && defined(PKGLIBDIR)
    _scriptPath = std::string(PKGLIBDIR) + "/scripts/";
 #else
-	_scriptPath = ctx.getApplicationPath() + "scripts/";
+	_scriptPath = ctx.getRuntimeDataPath() + "scripts/";
 #endif
 
 	// start the python interpreter
@@ -391,8 +390,10 @@ void ScriptingSystem::initialiseModule(const ApplicationContext& ctx)
 	rMessage() << getName() << ": Python interpreter initialised." << std::endl;
 
 	// Initialise the boost::python objects
-	_mainModule = boost::python::import("__main__");
-	_mainNamespace = _mainModule.attr("__dict__");
+	_mainObjects.reset(new BoostPythonMainObjects);
+
+	_mainObjects->mainModule = boost::python::import("__main__");
+	_mainObjects->mainNamespace = _mainObjects->mainModule.attr("__dict__");
 
 	try {
 		// Construct the console writer interface
@@ -400,7 +401,7 @@ void ScriptingSystem::initialiseModule(const ApplicationContext& ctx)
 		consoleWriter.def("write", &PythonConsoleWriter::write);
 
 		// Declare the interface to python
-		_mainNamespace["PythonConsoleWriter"] = consoleWriter;
+		_mainObjects->mainNamespace["PythonConsoleWriter"] = consoleWriter;
 
 		// Redirect stdio output to our local ConsoleWriter instances
 		boost::python::import("sys").attr("stderr") = boost::python::ptr(&_errorWriter);
@@ -416,7 +417,7 @@ void ScriptingSystem::initialiseModule(const ApplicationContext& ctx)
 	}
 
 	// Declare the std::vector<std::string> object to Python, this is used several times
-	_mainNamespace["StringVector"] = boost::python::class_< std::vector<std::string> >("StringVector")
+	_mainObjects->mainNamespace["StringVector"] = boost::python::class_< std::vector<std::string> >("StringVector")
 		.def(boost::python::vector_indexing_suite<std::vector<std::string>, true>())
 	;
 
@@ -485,6 +486,8 @@ void ScriptingSystem::shutdownModule()
 
 	// Clear the buffer so that nodes finally get destructed
 	SceneNodeBuffer::Instance().clear();
+    
+    _commands.clear();
 
 	_scriptPath.clear();
 
@@ -493,6 +496,9 @@ void ScriptingSystem::shutdownModule()
 
 	_initialised = false;
 
+	// Clear the boost::python::objects
+	_mainObjects.reset();
+
 	Py_Finalize();
 }
 
