@@ -15,6 +15,7 @@
 #include <wx/sizer.h>
 #include <wx/panel.h>
 
+#include "registry/registry.h"
 #include "LocalBitmapArtProvider.h"
 
 namespace ui
@@ -24,6 +25,7 @@ namespace
 {
 	const std::string RKEY_ROOT = "user/ui/groupDialog/";
 	const std::string RKEY_WINDOW_STATE = RKEY_ROOT + "window";
+	const std::string RKEY_LAST_SHOWN_PAGE = RKEY_ROOT + "lastShownPage";
 
 	const char* const WINDOW_TITLE = N_("Entity");
 }
@@ -54,6 +56,10 @@ void GroupDialog::construct()
 	GlobalRadiant().signal_radiantShutdown().connect(
         sigc::mem_fun(*InstancePtr(), &GroupDialog::onRadiantShutdown)
     );
+
+	GlobalRadiant().signal_radiantStarted().connect(
+		sigc::mem_fun(*InstancePtr(), &GroupDialog::onRadiantStartup)
+	);
 }
 
 void GroupDialog::reparentNotebook(wxWindow* newParent)
@@ -111,7 +117,7 @@ std::string GroupDialog::getPageName()
 	{
 		if (i.second.page == curPage)
 		{
-			// Found page. Set it to active if it is not already active.
+			// Found the page
 			return i.second.name;
 		}
 	}
@@ -123,9 +129,6 @@ std::string GroupDialog::getPageName()
 // Display the named page
 void GroupDialog::setPage(const std::string& name)
 {
-	// Force a Pageswitch to ensure the texture browser is properly redrawn.
-	setPage(_pages[0].page);
-
 	// Now search for the correct page.
 	for (Pages::value_type& i : _pages)
 	{
@@ -223,11 +226,29 @@ void GroupDialog::_postShow()
 {
 	TransientWindow::_postShow();
 
+	// Activate the most recently shown page
+	std::string lastShownPage = registry::getValue<std::string>(RKEY_LAST_SHOWN_PAGE);
+
+	if (!lastShownPage.empty())
+	{
+		setPage(lastShownPage);
+	}
+
 	// Unset the focus widget for this window to avoid the cursor
 	// from jumping into any entry fields
 	this->SetFocus();
 }
 
+void GroupDialog::onRadiantStartup()
+{
+	std::string lastShownPage = registry::getValue<std::string>(RKEY_LAST_SHOWN_PAGE);	
+	
+	if (!lastShownPage.empty())
+	{
+		setPage(lastShownPage);
+	}
+}
+
 void GroupDialog::onRadiantShutdown()
 {
 	if (IsShownOnScreen())
@@ -235,7 +256,7 @@ void GroupDialog::onRadiantShutdown()
 		Hide();
 	}
 
-    // Safely disconnect from the notebook before shutting down
+	// Safely disconnect from the notebook before shutting down
     _notebook->Disconnect(wxEVT_NOTEBOOK_PAGE_CHANGED,
                           wxBookCtrlEventHandler(GroupDialog::onPageSwitch), NULL, this);
 
@@ -278,12 +299,46 @@ wxWindow* GroupDialog::addPage(const PagePtr& page)
 		}
 	}
 
+	// greebo: Workaround to resolve #4551 in wxGTK:
+	// In Window Layouts with the GroupDialog in its own Window
+	// the attempt to Reparent() the page widget to the wxNotebook fails
+	// and the page gets cramped into the upper left corner.
+	// I can't figure the heck out why this happens, but it works when
+	// inserting a wxPanel and reparenting the page to that instead.
+#if false
+	// non-working code, stuff gets cramped into the upper left corner as if wrongly parented
 	page->page->Reparent(_notebook.get());
 	_notebook->InsertPage(insertPosition, page->page, page->tabLabel, false, imageId);
+#else
+	// Instantiate an intermediate wxPanel with the wxNotebook as parent
+	wxPanel* temp = new wxPanel(_notebook.get(), wxID_ANY);
+	temp->SetSizer(new wxBoxSizer(wxVERTICAL));
+
+	// Reparent the page widget to the panel
+	page->page->Reparent(temp);
+	temp->GetSizer()->Add(page->page, 1, wxEXPAND);
+
+	// We need to store the panel as page widget for switching functionality
+	page->page = temp;
+
+	_notebook->InsertPage(insertPosition, temp, page->tabLabel, false, imageId);
+#endif
 
 	// Add this page by copy to the local list
 	_pages.insert(std::make_pair(page->position, Page(*page)));
 
+	// During the startup phase (when pages are added) we want to activate the 
+	// newly added page if it was the active one during the last shutdown.
+	if (this->IsShownOnScreen())
+	{
+		std::string lastShownPage = registry::getValue<std::string>(RKEY_LAST_SHOWN_PAGE);
+
+		if (!lastShownPage.empty() && page->name == lastShownPage)
+		{
+			setPage(lastShownPage);
+		}
+	}
+
 	return page->page;
 }
 
@@ -315,6 +370,12 @@ void GroupDialog::updatePageTitle(int pageNumber)
 void GroupDialog::onPageSwitch(wxBookCtrlEvent& ev)
 {
 	updatePageTitle(ev.GetSelection());
+    
+	// Store the page's name into the registry for later retrieval
+	registry::setValue(RKEY_LAST_SHOWN_PAGE, getPageName());
+
+    // Be sure to skip the event, otherwise pages stay hidden
+    ev.Skip();
 }
 
 } // namespace ui
