@@ -1,8 +1,6 @@
 #pragma once
 
 #include "iradiant.h"
-#include "icommandsystem.h"
-
 #include <memory>
 
 namespace radiant
@@ -33,24 +31,19 @@ public:
     sigc::signal<void> signal_radiantStarted() const override;
     sigc::signal<void> signal_radiantShutdown() const override;
 
-    ThreadManager& getThreadManager();
+    ThreadManager& getThreadManager() override;
 	void performLongRunningOperation(
 		const std::function<void(ILongRunningOperation&)>& operationFunc,
-		const std::string& title);
+		const std::string& title) override;
 
 	// RegisterableModule implementation
-	const std::string& getName() const;
-	const StringSet& getDependencies() const;
-	void initialiseModule(const ApplicationContext& ctx);
-	void shutdownModule();
+	const std::string& getName() const override;
+	const StringSet& getDependencies() const override;
+	void initialiseModule(const ApplicationContext& ctx) override;
+	void shutdownModule() override;
 
 	// Stuff to be done after the modules have been loaded
 	void postModuleInitialisation();
-
-	void registerUICommands();
-
-	// Target method bound to the "Exit" command
-	static void exitCmd(const cmd::ArgumentList& args);
 };
 typedef std::shared_ptr<RadiantModule> RadiantModulePtr;
 
