@@ -11,7 +11,6 @@
 #include "Face.h"
 #include "FixedWinding.h"
 #include "math/Ray.h"
-#include "ui/surfaceinspector/SurfaceInspector.h"
 
 #include <functional>
 
@@ -460,8 +459,8 @@ void Brush::onFaceShaderChanged()
 {
     onFacePlaneChanged();
 
-    // Queue an UI update of the texture tools
-    ui::SurfaceInspector::update();
+    // Queue an UI update of the texture tools if any of them is listening
+	signal_faceShaderChanged().emit();
 }
 
 void Brush::onFaceConnectivityChanged()
@@ -583,7 +582,11 @@ void Brush::update_faces_wireframe(RenderablePointVector& wire,
                                    const std::size_t* visibleFaceIndices,
                                    std::size_t numVisibleFaces) const
 {
-    assert(numVisibleFaces <= _faceCentroidPoints.size());
+	if (numVisibleFaces > _faceCentroidPoints.size())
+	{
+		wire.clear();
+		return;
+	}
 
     // Assure that the pointvector can carry as many faces as are visible
     wire.resize(numVisibleFaces);
@@ -910,6 +913,12 @@ bool Brush::getIntersection(const Ray& ray, Vector3& intersection)
 	return true;
 }
 
+sigc::signal<void>& Brush::signal_faceShaderChanged()
+{
+	static sigc::signal<void> _sigFaceShaderChanged;
+	return _sigFaceShaderChanged;
+}
+
 void Brush::edge_push_back(FaceVertexId faceVertex) {
     m_select_edges.push_back(SelectableEdge(m_faces, faceVertex));
     for (Observers::iterator i = m_observers.begin(); i != m_observers.end(); ++i) {
