@@ -1,5 +1,6 @@
 #include "CamWnd.h"
 
+#include "igl.h"
 #include "ibrush.h"
 #include "iclipper.h"
 #include "iuimanager.h"
@@ -674,6 +675,12 @@ void CamWnd::Cam_Draw()
 
 		render::RenderableCollectionWalker::collectRenderablesInScene(renderer, _view);
 
+		// Render any active mousetools
+		for (const ActiveMouseTools::value_type& i : _activeMouseTools)
+		{
+			i.second->render(GlobalRenderSystem(), renderer, _view);
+		}
+
         renderer.render(_camera.modelview, _camera.projection);
     }
 
@@ -1108,6 +1115,7 @@ void CamWnd::forceRedraw()
         return;
     }
 
+	_wxGLWidget->Refresh(false);
     _wxGLWidget->Update();
 }
 
