@@ -8,6 +8,8 @@
 #include "log/LogStream.h"
 #include "modulesystem/ModuleRegistry.h"
 #include "modulesystem/ApplicationContextImpl.h"
+#include "ui/splash/Splash.h"
+#include <sigc++/functors/mem_fun.h>
 
 #ifndef POSIX
 #include "settings/LanguageManager.h"
@@ -17,6 +19,9 @@
 #include <wx/app.h>
 #include <wx/cmdline.h>
 
+#ifdef POSIX
+#include <libintl.h>
+#endif
 #include <exception>
 
 #if defined (_DEBUG) && defined (WIN32) && defined (_MSC_VER)
@@ -77,7 +82,7 @@ public:
         language::LanguageManager().init(_context);
 #endif
 
-#ifdef POSIX
+#if defined(POSIX) && !defined(__APPLE__)
         // greebo: not sure if this is needed
         // Other POSIX gettext initialisation
         setlocale(LC_ALL, "");
@@ -136,9 +141,14 @@ private:
         // (emits a warning if the file already exists (due to a previous startup failure))
         applog::PIDFile pidFile(PID_FILENAME);
 
-        module::ModuleRegistry::Instance().loadModules();
-        
-        module::ModuleRegistry::Instance().initialiseModules();
+#ifndef __linux__
+		// We skip the splash screen in Linux, but the other platforms will show a progress bar
+		// Connect the progress callback to the Splash instance.
+		module::ModuleRegistry::Instance().signal_moduleInitialisationProgress().connect(
+			sigc::mem_fun(ui::Splash::Instance(), &ui::Splash::setProgressAndText));
+#endif
+
+        module::ModuleRegistry::Instance().loadAndInitialiseModules();
 
         // Scope ends here, PIDFile is deleted by its destructor
 	}
