@@ -6,6 +6,7 @@
 #include "iscenegraph.h"
 #include "idialogmanager.h"
 #include "ieventmanager.h"
+#include "imodel.h"
 #include "ifilesystem.h"
 #include "ifiletypes.h"
 #include "iselectiongroup.h"
@@ -32,21 +33,19 @@
 #include "scene/BasicRootNode.h"
 #include "map/MapFileManager.h"
 #include "map/MapPositionManager.h"
-#include "map/PointFile.h"
+#include "map/StartupMapLoader.h"
 #include "map/RootNode.h"
 #include "map/MapResource.h"
-#include "map/algorithm/Clone.h"
 #include "map/algorithm/Merge.h"
 #include "map/algorithm/Traverse.h"
 #include "map/algorithm/MapExporter.h"
 #include "map/algorithm/Skins.h"
 #include "ui/mru/MRU.h"
 #include "ui/mainframe/ScreenUpdateBlocker.h"
-#include "ui/layers/LayerControlDialog.h"
 #include "ui/prefabselector/PrefabSelector.h"
 #include "selection/algorithm/Primitives.h"
 #include "selection/algorithm/Group.h"
-#include "selection/shaderclipboard/ShaderClipboard.h"
+#include "selection/algorithm/Transformation.h"
 #include "modulesystem/ModuleRegistry.h"
 #include "modulesystem/StaticModule.h"
 #include "RenderableAasFile.h"
@@ -100,6 +99,9 @@ void Map::loadMapResourceFromPath(const std::string& path)
     // Take the new node and insert it as map root
     GlobalSceneGraph().setRoot(_resource->getNode());
 
+	// Traverse the scenegraph and find the worldspawn
+	findWorldspawn();
+
     // Associate the Scenegaph with the global RenderSystem
     // This usually takes a while since all editor textures are loaded - display a dialog to inform the user
     {
@@ -150,6 +152,15 @@ bool Map::isUnnamed() const {
     return _mapName == _(MAP_UNNAMED_STRING);
 }
 
+void Map::onSceneNodeErase(const scene::INodePtr& node)
+{
+	// Detect when worldspawn is removed from the map
+	if (node == _worldSpawnNode)
+	{
+		_worldSpawnNode.reset();
+	}
+}
+
 void Map::setWorldspawn(const scene::INodePtr& node)
 {
     _worldSpawnNode = node;
@@ -182,7 +193,7 @@ MapFormatPtr Map::getFormatForFile(const std::string& filename)
     std::string gameType = GlobalGameManager().currentGame()->getKeyValue("type");
 
     MapFormatPtr mapFormat = GlobalMapFormatManager().getMapFormatForGameType(
-        gameType, path_get_extension(filename.c_str()));
+        gameType, os::getExtension(filename));
 
     ASSERT_MESSAGE(mapFormat != NULL, "map format not found for file " + filename);
 
@@ -362,7 +373,7 @@ scene::INodePtr Map::createWorldspawn()
 		GlobalEntityClassManager().findOrInsert("worldspawn", true)));
 
 	// We want the world spawn entity to go for the pole position
-	GlobalSceneGraph().root()->addChildNode(worldspawn);
+	GlobalSceneGraph().root()->addChildNodeToFront(worldspawn);
 
 	return worldspawn;
 }
@@ -388,9 +399,6 @@ void Map::load(const std::string& filename) {
         wxutil::ScopeTimer timer("map load");
 
 		loadMapResourceFromPath(_mapName);
-
-        // Traverse the scenegraph and find the worldspawn
-		findWorldspawn();
     }
 
     rMessage() << "--- LoadMapFile ---\n";
@@ -403,20 +411,9 @@ void Map::load(const std::string& filename) {
     // Move the view to a start position
     gotoStartPosition();
 
-    // Load the stored map positions from the worldspawn entity
-    GlobalMapPosition().loadPositions();
-    // Remove them, so that the user doesn't get bothered with them
-    GlobalMapPosition().removePositions();
-
-    // Clear the shaderclipboard, the references are most probably invalid now
-    GlobalShaderClipboard().clear();
-
     // Let the filtersystem update the filtered status of all instances
     GlobalFilterSystem().update();
 
-    // Update the layer control dialog
-    ui::LayerControlDialog::Instance().refresh();
-
     // Clear the modified flag
     setModified(false);
 }
@@ -428,27 +425,35 @@ bool Map::save(const MapFormatPtr& mapFormat)
     _saveInProgress = true;
 
     // Disable screen updates for the scope of this function
-    ui::ScreenUpdateBlocker blocker(_("Processing..."), _("Saving Map"));
+    ui::ScreenUpdateBlocker blocker(_("Processing..."), "");
+
+	blocker.setMessage(_("Preprocessing"));
+
+	try
+	{
+		signal_mapEvent().emit(IMap::MapSaving);
+	}
+	catch (std::runtime_error& ex)
+	{
+		wxutil::Messagebox::ShowError(
+			(boost::format(_("Failure running map pre-save event:\n%s")) % ex.what()).str());
+	}
 
     // Store the camview position into worldspawn
     saveCameraPosition();
 
-    // Store the map positions into the worldspawn spawnargs
-    GlobalMapPosition().savePositions();
-
-    PointFile::Instance().clear();
-
     wxutil::ScopeTimer timer("map save");
 
+	blocker.setMessage(_("Saving Map"));
+
     // Save the actual map resource
     bool success = _resource->save(mapFormat);
 
+	signal_mapEvent().emit(IMap::MapSaved);
+
     // Remove the saved camera position
     removeCameraPosition();
 
-    // Remove the map positions again after saving
-    GlobalMapPosition().removePositions();
-
     if (success)
     {
         // Clear the modified flag
@@ -519,7 +524,7 @@ bool Map::saveDirect(const std::string& filename, const MapFormatPtr& mapFormat)
     if (_saveInProgress) return false; // safeguard
 
     // Disable screen updates for the scope of this function
-    ui::ScreenUpdateBlocker blocker(_("Processing..."), path_get_filename_start(filename.c_str()));
+    ui::ScreenUpdateBlocker blocker(_("Processing..."), os::getFilename(filename));
 
     _saveInProgress = true;
 
@@ -547,7 +552,7 @@ bool Map::saveSelected(const std::string& filename, const MapFormatPtr& mapForma
     if (_saveInProgress) return false; // safeguard
 
     // Disable screen updates for the scope of this function
-    ui::ScreenUpdateBlocker blocker(_("Processing..."), path_get_filename_start(filename.c_str()));
+    ui::ScreenUpdateBlocker blocker(_("Processing..."), os::getFilename(filename));
 
     _saveInProgress = true;
 
@@ -724,7 +729,7 @@ void Map::loadPrefabAt(const Vector3& targetCoords)
         GlobalBrush().setTextureLock(true);
 
         // Translate the selection to the given point
-        GlobalSelectionSystem().translateSelected(targetCoords);
+        selection::algorithm::translateSelected(targetCoords);
 
         // Revert to previous state
         GlobalBrush().setTextureLock(prevTexLockState);
@@ -870,7 +875,7 @@ void Map::rename(const std::string& filename) {
 
 void Map::importSelected(std::istream& in)
 {
-    scene::INodePtr root(new scene::BasicRootNode);
+    scene::INodePtr root = std::make_shared<scene::BasicRootNode>();
 
     // Instantiate the default import filter
     class MapImportFilter :
@@ -965,6 +970,7 @@ const StringSet& Map::getDependencies() const
 	{
         _dependencies.insert(MODULE_RADIANT);
 		_dependencies.insert(MODULE_GAMEMANAGER);
+		_dependencies.insert(MODULE_SCENEGRAPH);
     }
 
     return _dependencies;
@@ -975,23 +981,29 @@ void Map::initialiseModule(const ApplicationContext& ctx)
     rMessage() << getName() << "::initialiseModule called." << std::endl;
 
     // Register for the startup event
-    _startupMapLoader = StartupMapLoaderPtr(new StartupMapLoader);
-    GlobalRadiant().signal_radiantStarted().connect(
-        sigc::mem_fun(*_startupMapLoader, &StartupMapLoader::onRadiantStartup)
-    );
-    GlobalRadiant().signal_radiantShutdown().connect(
-        sigc::mem_fun(*_startupMapLoader, &StartupMapLoader::onRadiantShutdown)
-    );
+    _startupMapLoader.reset(new StartupMapLoader);
+	_mapPositionManager.reset(new MapPositionManager);
+
+    GlobalSceneGraph().addSceneObserver(this);
 
     // Add the Map-related commands to the EventManager
     registerCommands();
 
-    // Add the map position commands to the EventManager
-    GlobalMapPosition().initialise();
+	_scaledModelExporter.initialise();
 
 	MapFileManager::registerFileTypes();
 }
 
+void Map::shutdownModule()
+{
+	_scaledModelExporter.shutdown();
+
+	GlobalSceneGraph().removeSceneObserver(this);
+
+	_startupMapLoader.reset();
+	_mapPositionManager.reset();
+}
+
 // Creates the static module instance
 module::StaticModule<Map> staticMapModule;
 
