@@ -21,13 +21,13 @@
 #include "debugging/debugging.h"
 #include "os/path.h"
 #include "os/file.h"
+#include "os/fs.h"
 #include "map/algorithm/Traverse.h"
 #include "stream/textfilestream.h"
 #include "scenelib.h"
 
 #include <functional>
 #include <boost/format.hpp>
-#include <boost/filesystem.hpp>
 
 #include "infofile/InfoFile.h"
 #include "string/string.h"
@@ -37,8 +37,6 @@
 #include "infofile/InfoFileExporter.h"
 #include "algorithm/ChildPrimitives.h"
 
-namespace fs = boost::filesystem;
-
 namespace map
 {
 
@@ -196,7 +194,7 @@ bool MapResource::saveBackup()
 		fs::path auxFile = fullpath;
 		auxFile.replace_extension(_infoFileExt);
 
-		if (file_writeable(fullpath.string().c_str()))
+		if (os::fileIsWritable(fullpath.string()))
 		{
 			fs::path backup = fullpath;
 			backup.replace_extension(".bak");
@@ -517,10 +515,10 @@ void MapResource::openFileStream(const std::string& path, const std::function<vo
 	}
 }
 
-bool MapResource::checkIsWriteable(const boost::filesystem::path& path)
+bool MapResource::checkIsWriteable(const fs::path& path)
 {
 	// Check writeability of the given file
-	if (boost::filesystem::exists(path) && !file_writeable(path.string().c_str()))
+	if (os::fileOrDirExists(path.string()) && !os::fileIsWritable(path))
 	{
 		// File is write-protected
 		rError() << "File is write-protected." << std::endl;
