@@ -5,6 +5,7 @@
 #include "debugging/debugging.h"
 #include "itextstream.h"
 #include "iregistry.h"
+#include "os/fs.h"
 #include "os/path.h"
 #include "os/dir.h"
 #include "log/PopupErrorHandler.h"
@@ -16,6 +17,8 @@
 #include <windows.h>
 #endif
 
+//#include <wx/msgout.h>
+
 namespace radiant
 {
 
@@ -24,6 +27,7 @@ namespace radiant
  */
 std::string ApplicationContextImpl::getApplicationPath() const
 {
+    //wxMessageOutputDebug().Output(wxString("Application Path is ") + _appPath);
 	return _appPath;
 }
 
@@ -31,6 +35,19 @@ std::string ApplicationContextImpl::getRuntimeDataPath() const
 {
 #if defined(POSIX) && defined (PKGDATADIR)
     return std::string(PKGDATADIR) + "/";
+#elif defined(__APPLE__)
+    // The Resources are in the Bundle folder Contents/Resources/, whereas the
+    // application binary is located in Contents/MacOS/
+    std::string path = getApplicationPath() + "../Resources/";
+    
+    // When launching the app from Xcode, the Resources/ folder
+    // is next to the binary
+    if (!fs::exists(path))
+    {
+        path = getApplicationPath() + "Resources/";
+    }
+    
+    return path;
 #else
     return getApplicationPath();
 #endif
@@ -43,6 +60,7 @@ std::string ApplicationContextImpl::getSettingsPath() const
 
 std::string ApplicationContextImpl::getBitmapsPath() const
 {
+    //wxMessageOutputDebug().Output(wxString("RTD Path is ") + getRuntimeDataPath());
 	return getRuntimeDataPath() + "bitmaps/";
 }
 
@@ -75,50 +93,100 @@ std::mutex& ApplicationContextImpl::getStreamLock() const
 // ============== OS-Specific Implementations go here ===================
 
 // ================ POSIX ====================
-#if defined(POSIX)
+#if defined(POSIX) || defined(__APPLE__)
 
 #include <stdlib.h>
 #include <pwd.h>
 #include <unistd.h>
+#ifdef __APPLE__
+#include <libproc.h>
+#endif
+    
+namespace
+{
 
+#ifdef __APPLE__
+
+// greebo: In OSX, we use the proc_pidpath() function
+// to determine the absolute path of this PID
+std::string getExecutablePath(char* argv[])
+{
+    pid_t pid = getpid();
+    
+    char pathBuf[PROC_PIDPATHINFO_MAXSIZE];
+    int ret = proc_pidpath(pid, pathBuf, sizeof(pathBuf));
+    
+    if (ret > 0)
+    {
+        // Success
+        fs::path execPath = std::string(pathBuf);
+        fs::path appPath = execPath.remove_leaf();
+
+        rConsole() << "Application path: " << appPath << std::endl;
+        
+        return appPath.string();
+    }
+    
+    // Error, terminate the app
+    rConsoleError() << "ApplicationContextImpl: could not get app path: "
+        << strerror(errno) << std::endl;
+    
+    throw std::runtime_error("ApplicationContextImpl: could not get app path");
+}
+    
+#else // generic POSIX
+    
 const char* LINK_NAME =
 #if defined (__linux__)
   "/proc/self/exe"
-#else // FreeBSD and OSX
+#else // FreeBSD
   "/proc/curproc/file"
 #endif
 ;
 
 /// brief Returns the filename of the executable belonging to the current process, or 0 if not found.
-char* getexename(char *buf, char* argv[]) {
-	/* Now read the symbolic link */
+std::string getExecutablePath(char* argv[])
+{
+    char buf[PATH_MAX];
+    
+	// Now read the symbolic link
 	int ret = readlink(LINK_NAME, buf, PATH_MAX);
 
-	if (ret == -1) {
-		rMessage() << "getexename: falling back to argv[0]: '" << argv[0] << "'";
+	if (ret == -1)
+    {
+		rMessage() << "getexename: falling back to argv[0]: '" << argv[0] << "'\n";
+        
 		const char* path = realpath(argv[0], buf);
-		if (path == NULL) {
-			/* In case of an error, leave the handling up to the caller */
-			return "";
+        
+		if (path == nullptr)
+        {
+			// In case of an error, leave the handling up to the caller
+			return std::string();
 		}
 	}
 
 	/* Ensure proper NUL termination */
-	buf[ret] = 0;
+	buf[ret] = '\0';
 
 	/* delete the program name */
 	*(strrchr(buf, '/')) = '\0';
 
 	// NOTE: we build app path with a trailing '/'
 	// it's a general convention in Radiant to have the slash at the end of directories
-	if (buf[strlen(buf)-1] != '/') {
+	if (buf[strlen(buf)-1] != '/')
+    {
 		strcat(buf, "/");
 	}
 
-	return buf;
+	return std::string(buf);
+}
+    
+#endif
+
 }
 
-void ApplicationContextImpl::initialise(int argc, char* argv[]) {
+void ApplicationContextImpl::initialise(int argc, char* argv[])
+{
 	// Give away unnecessary root privileges.
 	// Important: must be done before calling gtk_init().
 	char *loginname;
@@ -140,12 +208,9 @@ void ApplicationContextImpl::initialise(int argc, char* argv[]) {
     os::makeDirectory(home);
     _homePath = home;
 
-	{
-		char real[PATH_MAX];
-		_appPath = getexename(real, argv);
-		ASSERT_MESSAGE(!_appPath.empty(), "failed to deduce app path");
-	}
-
+	_appPath = getExecutablePath(argv);
+    ASSERT_MESSAGE(!_appPath.empty(), "failed to deduce app path");
+	
 	// Initialise the relative paths
 	initPaths();
 }
