@@ -1,5 +1,7 @@
 #include "Transformation.h"
 
+#include <functional>
+
 #include "i18n.h"
 #include <string>
 #include <map>
@@ -20,6 +22,8 @@
 #include "map/algorithm/Clone.h"
 #include "scene/BasicRootNode.h"
 #include "debugging/debugging.h"
+#include "selection/TransformationVisitors.h"
+#include "selection/SceneWalkers.h"
 
 #include <boost/algorithm/string/case_conv.hpp>
 
@@ -29,6 +33,27 @@ namespace selection
 namespace algorithm
 {
 
+void rotateSelected(const Quaternion& rotation)
+{
+	// Perform the rotation according to the current mode
+	if (GlobalSelectionSystem().Mode() == SelectionSystem::eComponent)
+	{
+		GlobalSelectionSystem().foreachSelectedComponent(
+			RotateComponentSelected(rotation, GlobalSelectionSystem().getPivot2World().t().getVector3()));
+	}
+	else
+	{
+		// Cycle through the selections and rotate them
+		GlobalSelectionSystem().foreachSelected(RotateSelected(rotation,
+			GlobalSelectionSystem().getPivot2World().t().getVector3()));
+	}
+
+	// Update the views
+	SceneChangeNotify();
+
+	GlobalSceneGraph().foreachNode(scene::freezeTransformableNode);
+}
+
 // greebo: see header for documentation
 void rotateSelected(const Vector3& eulerXYZ)
 {
@@ -36,7 +61,7 @@ void rotateSelected(const Vector3& eulerXYZ)
 	command += string::to_string(eulerXYZ);
 	UndoableCommand undo(command.c_str());
 
-	GlobalSelectionSystem().rotateSelected(Quaternion::createForEulerXYZDegrees(eulerXYZ));
+	rotateSelected(Quaternion::createForEulerXYZDegrees(eulerXYZ));
 }
 
 // greebo: see header for documentation
@@ -48,11 +73,27 @@ void scaleSelected(const Vector3& scaleXYZ)
 	{
 		std::string command("scaleSelected: ");
 		command += string::to_string(scaleXYZ);
-		UndoableCommand undo(command.c_str());
+		UndoableCommand undo(command);
 
-		GlobalSelectionSystem().scaleSelected(scaleXYZ);
+		// Pass the scale to the according traversor
+		if (GlobalSelectionSystem().Mode() == SelectionSystem::eComponent)
+		{
+			GlobalSelectionSystem().foreachSelectedComponent(ScaleComponentSelected(scaleXYZ, 
+				GlobalSelectionSystem().getPivot2World().t().getVector3()));
+		}
+		else
+		{
+			GlobalSelectionSystem().foreachSelected(ScaleSelected(scaleXYZ, 
+				GlobalSelectionSystem().getPivot2World().t().getVector3()));
+		}
+
+		// Update the scene views
+		SceneChangeNotify();
+
+		GlobalSceneGraph().foreachNode(scene::freezeTransformableNode);
 	}
-	else {
+	else 
+	{
 		wxutil::Messagebox::ShowError(_("Cannot scale by zero value."));
 	}
 }
@@ -120,32 +161,36 @@ public:
 		if (Node_isSelected(node))
 		{
 			// Clone the current node
-			scene::INodePtr clone = map::Node_Clone(node);
+			scene::INodePtr clone = map::cloneNodeIncludingDescendants(node,
+				sigc::mem_fun(*this, &SelectionCloner::postProcessClonedNode));
 
 			// Add the cloned node and its parent to the list
 			_cloned.insert(Map::value_type(clone, node->getParent()));
 
 			// Insert this node in the root
 			_cloneRoot->addChildNode(clone);
+		}
+	}
 
-			// Collect and add the group IDs of the source node
-			std::shared_ptr<IGroupSelectable> groupSelectable = std::dynamic_pointer_cast<IGroupSelectable>(node);
+	void postProcessClonedNode(const scene::INodePtr& sourceNode, const scene::INodePtr& clonedNode)
+	{
+		// Collect and add the group IDs of the source node
+		std::shared_ptr<IGroupSelectable> groupSelectable = std::dynamic_pointer_cast<IGroupSelectable>(sourceNode);
 
-			if (groupSelectable)
+		if (groupSelectable)
+		{
+			const IGroupSelectable::GroupIds& groupIds = groupSelectable->getGroupIds();
+
+			// Get the Groups the source node was assigned to, and add the
+			// cloned node to the mapped group, one by one, keeping the order intact
+			for (std::size_t id : groupIds)
 			{
-				const IGroupSelectable::GroupIds& groupIds = groupSelectable->getGroupIds();
+				// Try to insert the ID, ignore if already exists
+				// Get a new mapping for the given group ID
+				const ISelectionGroupPtr& mappedGroup = getMappedGroup(id);
 
-				// Get the Groups the source node was assigned to, and add the
-				// cloned node to the mapped group, one by one, keeping the order intact
-				for (std::size_t id : groupIds)
-				{
-					// Try to insert the ID, ignore if already exists
-					// Get a new mapping for the given group ID
-					const ISelectionGroupPtr& mappedGroup = getMappedGroup(id);
-
-					// Assign the new group ID to this clone
-					mappedGroup->addNode(clone);
-				}
+				// Assign the new group ID to this clone
+				mappedGroup->addNode(clonedNode);
 			}
 		}
 	}
@@ -279,22 +324,41 @@ Vector3 AxisBase_axisForDirection(const AxisBase& axes, ENudgeDirection directio
 	return Vector3(0, 0, 0);
 }
 
+void translateSelected(const Vector3& translation)
+{
+	// Apply the transformation and freeze the changes
+	if (GlobalSelectionSystem().Mode() == SelectionSystem::eComponent)
+	{
+		GlobalSelectionSystem().foreachSelectedComponent(TranslateComponentSelected(translation));
+	}
+	else
+	{
+		// Cycle through the selected items and apply the translation
+		GlobalSelectionSystem().foreachSelected(TranslateSelected(translation));
+	}
+
+	// Update the scene so that the changes are made visible
+	SceneChangeNotify();
+
+	GlobalSceneGraph().foreachNode(scene::freezeTransformableNode);
+}
+
 // Specialised overload, called by the general nudgeSelected() routine
 void nudgeSelected(ENudgeDirection direction, float amount, EViewType viewtype)
 {
 	AxisBase axes(AxisBase_forViewType(viewtype));
 
-	Vector3 view_direction(-axes.z);
+	//Vector3 view_direction(-axes.z);
 	Vector3 nudge(AxisBase_axisForDirection(axes, direction) * amount);
 
-	if (GlobalSelectionSystem().ManipulatorMode() == SelectionSystem::eTranslate ||
-        GlobalSelectionSystem().ManipulatorMode() == SelectionSystem::eDrag ||
-        GlobalSelectionSystem().ManipulatorMode() == SelectionSystem::eClip)
+	if (GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Translate ||
+        GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Drag ||
+        GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Clip)
     {
-        GlobalSelectionSystem().translateSelected(nudge);
+        translateSelected(nudge);
 
         // In clip mode, update the clipping plane
-        if (GlobalSelectionSystem().ManipulatorMode() == SelectionSystem::eClip)
+        if (GlobalSelectionSystem().getActiveManipulatorType() == selection::Manipulator::Clip)
         {
             GlobalClipper().update();
         }
@@ -342,7 +406,7 @@ void nudgeByAxis(int nDim, float fNudge)
 	Vector3 translate(0, 0, 0);
 	translate[nDim] = fNudge;
 
-	GlobalSelectionSystem().translateSelected(translate);
+	translateSelected(translate);
 }
 
 void moveSelectedAlongZ(float amount)
@@ -439,24 +503,20 @@ void rotateSelectionAboutAxis(axis_t axis, float deg)
 {
 	if (fabs(deg) == 90.0f)
 	{
-		GlobalSelectionSystem().rotateSelected(
-			quaternion_for_axis90(axis, (deg > 0) ? eSignPositive : eSignNegative));
+		rotateSelected(quaternion_for_axis90(axis, (deg > 0) ? eSignPositive : eSignNegative));
 	}
 	else
 	{
 		switch(axis)
 		{
 		case 0:
-			GlobalSelectionSystem().rotateSelected(
-				Quaternion::createForMatrix(Matrix4::getRotationAboutXDegrees(deg)));
+			rotateSelected(Quaternion::createForMatrix(Matrix4::getRotationAboutXDegrees(deg)));
 			break;
 		case 1:
-			GlobalSelectionSystem().rotateSelected(
-				Quaternion::createForMatrix(Matrix4::getRotationAboutYDegrees(deg)));
+			rotateSelected(Quaternion::createForMatrix(Matrix4::getRotationAboutYDegrees(deg)));
 			break;
 		case 2:
-			GlobalSelectionSystem().rotateSelected(
-				Quaternion::createForMatrix(Matrix4::getRotationAboutZDegrees(deg)));
+			rotateSelected(Quaternion::createForMatrix(Matrix4::getRotationAboutZDegrees(deg)));
 			break;
 		}
 	}
@@ -503,7 +563,7 @@ void mirrorSelection(int axis)
 	Vector3 flip(1, 1, 1);
 	flip[axis] = -1;
 
-	GlobalSelectionSystem().scaleSelected(flip);
+	scaleSelected(flip);
 }
 
 void mirrorSelectionX(const cmd::ArgumentList& args)
