@@ -4,7 +4,7 @@
 #include "iselectiontest.h"
 #include "iscenegraph.h"
 #include "iuimanager.h"
-#include "ui/mediabrowser/MediaBrowser.h"
+#include "imediabrowser.h"
 #include "ui/texturebrowser/TextureBrowser.h"
 #include "ClosestTexturableFinder.h"
 
@@ -12,7 +12,8 @@
 #include "brush/BrushNode.h"
 #include <boost/format.hpp>
 
-namespace selection {
+namespace selection 
+{
 
 ShaderClipboard::ShaderClipboard() :
 	_updatesDisabled(false)
@@ -24,13 +25,17 @@ ShaderClipboard::ShaderClipboard() :
 		_("The name of the shader in the clipboard")
 	);
 
-	GlobalUndoSystem().addObserver(this);
+	GlobalUndoSystem().signal_postUndo().connect(
+		sigc::mem_fun(this, &ShaderClipboard::onUndoRedoOperation));
+	GlobalUndoSystem().signal_postRedo().connect(
+		sigc::mem_fun(this, &ShaderClipboard::onUndoRedoOperation));
 
 	GlobalMapModule().signal_mapEvent().connect(
 		sigc::mem_fun(*this, &ShaderClipboard::onMapEvent));
 }
 
-void ShaderClipboard::clear() {
+void ShaderClipboard::clear() 
+{
 	_source.clear();
 
 	_updatesDisabled = true;
@@ -41,16 +46,7 @@ void ShaderClipboard::clear() {
 	_updatesDisabled = false;
 }
 
-void ShaderClipboard::postUndo()
-{
-	// Check if the source is still valid
-	if (!_source.checkValid())
-	{
-		clear();
-	}
-}
-
-void ShaderClipboard::postRedo()
+void ShaderClipboard::onUndoRedoOperation()
 {
 	// Check if the source is still valid
 	if (!_source.checkValid())
@@ -69,22 +65,24 @@ Texturable ShaderClipboard::getTexturable(SelectionTest& test) {
 	return returnValue;
 }
 
-void ShaderClipboard::updateMediaBrowsers() {
+void ShaderClipboard::updateMediaBrowsers()
+{
 	// Avoid nasty loopbacks
 	_updatesDisabled = true;
 
 	// Set the active shader in the Texture window as well
 	GlobalTextureBrowser().setSelectedShader(_source.getShader());
+
 	std::string sourceShader = _source.getShader();
-	ui::MediaBrowser::getInstance().setSelection(sourceShader);
+	GlobalMediaBrowser().setSelection(sourceShader);
 
 	_updatesDisabled = false;
 
 	updateStatusText();
 }
 
-void ShaderClipboard::updateStatusText() {
-
+void ShaderClipboard::updateStatusText()
+{
 	std::string statusText;
 
 	if (!_source.empty()) {
@@ -167,8 +165,9 @@ sigc::signal<void> ShaderClipboard::signal_sourceChanged() const
 
 void ShaderClipboard::onMapEvent(IMap::MapEvent ev)
 {
-	if (ev == IMap::MapUnloading)
+	if (ev == IMap::MapUnloading || ev == IMap::MapLoaded)
 	{
+		// Clear the shaderclipboard, the references are most probably invalid now
 		clear();
 	}
 }
@@ -176,7 +175,8 @@ void ShaderClipboard::onMapEvent(IMap::MapEvent ev)
 } // namespace selection
 
 // global accessor function
-selection::ShaderClipboard& GlobalShaderClipboard() {
+selection::ShaderClipboard& GlobalShaderClipboard()
+{
 	static selection::ShaderClipboard _instance;
 
 	return _instance;
