@@ -12,7 +12,7 @@ GameFileLoader::GameFileLoader(Manager::GameMap& games, const std::string& path)
 {}
 
 // Main functor () function, gets called with the file (without path)
-void GameFileLoader::operator() (const boost::filesystem::path& file)
+void GameFileLoader::operator() (const fs::path& file)
 {
 	if (boost::algorithm::to_lower_copy(file.extension().string()) != GAME_FILE_EXT)
 	{
