@@ -13,6 +13,7 @@
 #include <wx/tglbtn.h>
 #include <wx/artprov.h>
 #include <wx/sizer.h>
+#include <wx/panel.h>
 
 #include "layers/LayerSystem.h"
 #include "LayerControlDialog.h"
@@ -29,7 +30,9 @@ namespace
 }
 
 LayerControl::LayerControl(wxWindow* parent, int layerID) :
-	_layerID(layerID)
+	_layerID(layerID),
+	_activeColour(0,0,0),
+	_inactiveColour(90,90,90,1)
 {
 	// Create the toggle button
 	_toggle = new wxBitmapToggleButton(parent, wxID_ANY, 
@@ -37,6 +40,16 @@ LayerControl::LayerControl(wxWindow* parent, int layerID) :
 	_toggle->SetMaxSize(wxSize(30, -1));
 	_toggle->Connect(wxEVT_TOGGLEBUTTON, wxCommandEventHandler(LayerControl::onToggle), NULL, this);
 
+	Vector3 selColour = ColourSchemes().getColour("selected_brush");
+	_activeColour = wxColour(static_cast<unsigned char>(selColour[0] * 255),
+		static_cast<unsigned char>(selColour[1] * 255),
+		static_cast<unsigned char>(selColour[2] * 255));
+
+	_statusWidget = new wxPanel(parent, wxID_ANY);
+	_statusWidget->SetMinSize(wxSize(5, -1));
+	_statusWidget->SetToolTip(_("Indicates whether anything among the current selection is part of this layer."));
+	_statusWidget->SetBackgroundColour(_inactiveColour);
+
 	// Create the label
 	_labelButton = new wxButton(parent, wxID_ANY);
 	_labelButton->Connect(wxEVT_BUTTON, wxCommandEventHandler(LayerControl::onLayerSelect), NULL, this);
@@ -68,6 +81,11 @@ wxButton* LayerControl::getLabelButton()
 	return _labelButton;
 }
 
+wxWindow* LayerControl::getStatusWidget()
+{
+	return _statusWidget;
+}
+
 wxSizer* LayerControl::getButtons()
 {
 	return _buttonHBox;
@@ -111,9 +129,23 @@ void LayerControl::update()
 	// Don't allow selection of hidden layers
 	_labelButton->Enable(layerIsVisible);
 
+	// Clear usage status
+	_statusWidget->SetBackgroundColour(_inactiveColour);
+
 	_updateActive = false;
 }
 
+int LayerControl::getLayerId() const
+{
+	return _layerID;
+}
+
+void LayerControl::updateUsageStatusWidget(std::size_t numUsedObjectsInLayer)
+{
+	_statusWidget->SetBackgroundColour(numUsedObjectsInLayer > 0 ? _activeColour : _inactiveColour);
+	_statusWidget->Refresh(true);
+}
+
 void LayerControl::onToggle(wxCommandEvent& ev)
 {
 	if (_updateActive) return;
@@ -136,7 +168,6 @@ void LayerControl::onDelete(wxCommandEvent& ev)
 		scene::getLayerSystem().deleteLayer(
 			scene::getLayerSystem().getLayerName(_layerID)
 		);
-		LayerControlDialog::Instance().refresh();
 	}
 }
 
@@ -166,9 +197,8 @@ void LayerControl::onRename(wxCommandEvent& ev)
 
 		if (success)
 		{
-			// Reload the widgets, we're done here
-			update();
-			break;
+			// Stop here, the control might already have been destroyed
+			return;
 		}
 		else
 		{
