@@ -8,6 +8,8 @@
 #include "iuimanager.h"
 #include "iradiant.h"
 #include "imainframe.h"
+#include "iselection.h"
+#include "iundo.h"
 
 #include <wx/tglbtn.h>
 #include <wx/clrpicker.h>
@@ -225,26 +227,16 @@ void LightInspector::update()
     }
 }
 
-void LightInspector::postUndo()
-{
-	// Update the LightInspector after an undo operation
-	update();
-}
-
-void LightInspector::postRedo()
-{
-	// Update the LightInspector after a redo operation
-	update();
-}
-
 // Pre-hide callback
 void LightInspector::_preHide()
 {
 	TransientWindow::_preHide();
 
 	// Remove as observer, an invisible inspector doesn't need to receive events
-	GlobalSelectionSystem().removeObserver(this);
-	GlobalUndoSystem().removeObserver(this);
+	_selectionChanged.disconnect();
+
+	_undoHandler.disconnect();
+	_redoHandler.disconnect();
 }
 
 // Pre-show callback
@@ -252,19 +244,24 @@ void LightInspector::_preShow()
 {
 	TransientWindow::_preShow();
 
+	_selectionChanged.disconnect();
+	_undoHandler.disconnect();
+	_redoHandler.disconnect();
+
 	// Register self as observer to receive events
-	GlobalUndoSystem().addObserver(this);
-	GlobalSelectionSystem().addObserver(this);
+	_undoHandler = GlobalUndoSystem().signal_postUndo().connect(
+		sigc::mem_fun(this, &LightInspector::update));
+	_redoHandler = GlobalUndoSystem().signal_postRedo().connect(
+		sigc::mem_fun(this, &LightInspector::update));
+
+	// Register self to the SelSystem to get notified upon selection changes.
+	_selectionChanged = GlobalSelectionSystem().signal_selectionChanged().connect(
+		[this](const ISelectable&) { update(); });
 
 	// Update the widgets before showing
 	update();
 }
 
-void LightInspector::selectionChanged(const scene::INodePtr& node, bool isComponent)
-{
-	update();
-}
-
 // Static method to toggle the dialog
 void LightInspector::toggleInspector(const cmd::ArgumentList& args)
 {
