@@ -12,7 +12,6 @@
 
 #include "log/Console.h"
 #include "xyview/GlobalXYWnd.h"
-#include "ui/mediabrowser/MediaBrowser.h"
 #include "camera/GlobalCamera.h"
 
 #include "registry/registry.h"
@@ -108,6 +107,9 @@ void MainFrame::initialiseModule(const ApplicationContext& ctx)
 	);
 	GlobalEventManager().addCommand("ToggleFullScreenCamera", "ToggleFullScreenCamera");
 
+	GlobalCommandSystem().addCommand("Exit", sigc::mem_fun(this, &MainFrame::exitCmd));
+	GlobalEventManager().addCommand("Exit", "Exit");
+
 #ifdef WIN32
 	HMODULE lib = LoadLibrary(L"dwmapi.dll");
 
@@ -144,6 +146,16 @@ void MainFrame::shutdownModule()
 	disableScreenUpdates();
 }
 
+void MainFrame::exitCmd(const cmd::ArgumentList& args)
+{
+	// Just tell the main application window to close, which will invoke
+	// appropriate event handlers.
+	if (getWxTopLevelWindow() != nullptr)
+	{
+		getWxTopLevelWindow()->Close(false /* don't force */);
+	}
+}
+
 void MainFrame::keyChanged()
 {
 #ifdef WIN32
@@ -216,6 +228,22 @@ void MainFrame::construct()
 		}
 	}
 
+#ifdef __linux__
+	// #4526: In Linux, do another restore after the top level window has been shown
+	// After startup, GTK emits onSizeAllocate events which trigger a Layout() sequence
+	// messing up the pane positions, so do the restore() one more time after the main
+	// window came up.
+	_topLevelWindow->Bind(wxEVT_SHOW, [&](wxShowEvent& ev)
+	{
+		if (_currentLayout && ev.IsShown())
+		{
+			_currentLayout->restoreStateFromRegistry();
+		}
+
+		ev.Skip();
+	});
+#endif
+
 	// register the commands
 	GlobalMainFrameLayoutManager().registerCommands();
 
@@ -359,21 +387,6 @@ void MainFrame::create()
 	// Create the topmost window first
 	createTopLevelWindow();
 
-	/* Construct the Group Dialog. This is the tabbed window that contains
-     * a number of pages - usually Entities, Textures and possibly Console.
-     */
-	// Add the Media Browser page
-	IGroupDialog::PagePtr mediaBrowserPage(new IGroupDialog::Page);
-
-	mediaBrowserPage->name = "mediabrowser";
-	mediaBrowserPage->windowLabel = _("Media");
-	mediaBrowserPage->page = MediaBrowser::getInstance().getWidget();
-	mediaBrowserPage->tabIcon = "folder16.png";
-	mediaBrowserPage->tabLabel = _("Media");
-	mediaBrowserPage->position = IGroupDialog::Page::Position::MediaBrowser;
-
-	GlobalGroupDialog().addPage(mediaBrowserPage);
-
     // Add the console
 	IGroupDialog::PagePtr consolePage(new IGroupDialog::Page);
 
