@@ -122,7 +122,7 @@ XYWnd::XYWnd(int id, wxWindow* parent) :
 	_wxGLWidget->Connect(wxEVT_IDLE, wxIdleEventHandler(XYWnd::onIdle), NULL, this);
 
 	_freezePointer.connectMouseEvents(
-		wxutil::FreezePointer::MouseEventFunction(),
+		std::bind(&XYWnd::onGLMouseButtonPress, this, std::placeholders::_1),
 		std::bind(&XYWnd::onGLMouseButtonRelease, this, std::placeholders::_1));
 
     updateProjection();
@@ -258,6 +258,7 @@ void XYWnd::forceRedraw()
         return;
     }
 
+	_wxGLWidget->Refresh(false);
     _wxGLWidget->Update();
 }
 
@@ -1313,6 +1314,13 @@ void XYWnd::draw()
         render::RenderableCollectionWalker::collectRenderablesInScene(renderer,
                                                                       _view);
 
+
+		// Render any active mousetools
+		for (const ActiveMouseTools::value_type& i : _activeMouseTools)
+		{
+			i.second->render(GlobalRenderSystem(), renderer, _view);
+		}
+
         // Second pass (GL calls)
         renderer.render(_modelView, _projection);
     }
